import { SvelteComponentTyped } from "svelte";
declare const __propDef: {
    props: {
        /** Determines if any field change will cause form re-validation. */ active: boolean;
        /** Read-only binding indicating validation result. */ valid?: boolean | undefined;
        /** Read-only binding for validation error messages. */ errors?: string[] | undefined;
    };
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export type FormValidatorBindProps = typeof __propDef.props;
export type FormValidatorBindEvents = typeof __propDef.events;
export type FormValidatorBindSlots = typeof __propDef.slots;
/**
 * Provides Svelte bindings for Semantic-UI Form validator or Yup validator.
 * In both cases the <FormValidationData> tag must be a child of the Semantic UI form component.
 *
 * https://semantic-ui.com/behaviors/form.html
 *
 * https://github.com/jquense/yup
 *
 * Example:
 * ```
 * <form calss="ui form" use:formValidation={{ inline: true }}>
 *     <FormValidationData // TODO FormValidator
 *         active={isActive}
 *         bind:valid={isValid}
 *         bind:errors={errors}
 *     />
 *     ...
 * </form>
 * <p>This form {#if isValid} is good {:else} has errors {/if} </p>
 * ```
 */
export default class FormValidatorBind extends SvelteComponentTyped<FormValidatorBindProps, FormValidatorBindEvents, FormValidatorBindSlots> {
}
export {};
