/**
 * 'fmt' and 'parse' utility object, input formatter classes.
 * @module data/format
 */
import { SettingsHelper, pad } from "./common";
import { calendarDefaults } from "../components/use-calendar";
export const numberDefaults = new SettingsHelper("number");
// TODO: Global fmt and parse objects with default formatting settings.
// Lazily initialized, to give user the chance to change defaults.
/*
 .8888b              dP
 88   "              88
 88aaa  88d8b.d8b. d8888P
 88     88'`88'`88   88
 88     88  88  88   88
 dP     dP  dP  dP   dP

*/
// this function is copied from fomantic-ui calendar component v2.9.3
function weekOfYear(weekYear, weekMonth, weekDay) {
    // adapted from http://www.merlyn.demon.co.uk/weekcalc.htm
    /* eslint-disable @typescript-eslint/typedef */
    const ms1d = 24 * 3600 * 1000, ms7d = 7 * ms1d, DC3 = Date.UTC(weekYear, weekMonth, weekDay + 3) / ms1d, // an absolute day number
    AWN = Math.floor(DC3 / 7), // an absolute week number
    Wyr = new Date(AWN * ms7d).getUTCFullYear();
    /* eslint-enable */
    return AWN - Math.floor(Date.UTC(Wyr, 0, 7) / ms7d) + 1;
}
// this function is copied from fomantic-ui calendar component v2.9.3
export function dateFormat(format, date) {
    if (!(date instanceof Date)) {
        return "";
    }
    const settings = calendarDefaults.read();
    /* eslint-disable @typescript-eslint/typedef, @typescript-eslint/quotes */
    const D = date.getDate(), M = date.getMonth(), Y = date.getFullYear(), d = date.getDay(), H = date.getHours(), m = date.getMinutes(), s = date.getSeconds(), w = /*module.get.*/ weekOfYear(Y, M, D + 1 - settings.firstDayOfWeek), h = H % 12 || 12, a = H < 12 ? settings.text.am.toLowerCase() : settings.text.pm.toLowerCase(), tokens = {
        D: D,
        DD: ("0" + D).slice(-2),
        M: M + 1,
        MM: ("0" + (M + 1)).slice(-2),
        MMM: settings.text.monthsShort[M],
        MMMM: settings.text.months[M],
        Y: Y,
        YY: String(Y).slice(2),
        YYYY: Y,
        d: d,
        dd: settings.text.days[d],
        ddd: settings.text.days[d],
        dddd: settings.text.days[d],
        // dd: settings.text.dayNamesShort[d].slice(0, 2),
        // ddd: settings.text.dayNamesShort[d],
        // dddd: settings.text.dayNames[d],
        h: h,
        hh: ("0" + h).slice(-2),
        H: H,
        HH: ("0" + H).slice(-2),
        m: m,
        mm: ("0" + m).slice(-2),
        s: s,
        ss: ("0" + s).slice(-2),
        a: a,
        A: a.toUpperCase(),
        S: ["th", "st", "nd", "rd"][D % 10 > 3 ? 0 : (D % 100) - (D % 10) === 10 ? 0 : D % 10],
        w: w,
        ww: ("0" + w).slice(-2),
    };
    /* eslint-enable */
    return format.replace(settings.regExp.token, function (match) {
        if (match in tokens) {
            return tokens[match];
        }
        return match.slice(1, -1);
    });
}
export const fmt = {
    isoDate: (d) => {
        if (!d || !d.getDate) {
            return "";
        }
        const day = pad(d.getDate(), 2);
        const month = pad(d.getMonth() + 1, 2);
        const year = pad(d.getFullYear(), 4);
        return `${year}-${month}-${day}`;
    },
    isoTime: (d) => {
        if (!d || !d.getDate) {
            return "";
        }
        const hour = pad(d.getHours(), 2);
        const minute = pad(d.getMinutes(), 2);
        return `${hour}:${minute}`;
    },
    date: (d) => {
        if (!d || !d.getDate) {
            return "";
        }
        const settings = calendarDefaults.read();
        return dateFormat(settings.formatter.date, d);
    },
    time: (d) => {
        if (!d || !d.getDate) {
            return "";
        }
        const settings = calendarDefaults.read();
        return dateFormat(settings.formatter.time, d);
    },
};
/*

 88d888b. .d8888b. 88d888b. .d8888b. .d8888b.
 88'  `88 88'  `88 88'  `88 Y8ooooo. 88ooood8
 88.  .88 88.  .88 88             88 88.  ...
 88Y888P' `88888P8 dP       `88888P' `88888P'
 88
 dP
*/
export const parse = {
    isoDate: (value) => {
        const d = new Date(value);
        return d;
    },
};
/*
          dP                                             dP
          88                                             88
 .d8888b. 88d888b. .d8888b. 88d888b. .d8888b. .d8888b. d8888P
 88'  `"" 88'  `88 88'  `88 88'  `88 Y8ooooo. 88ooood8   88
 88.  ... 88    88 88.  .88 88             88 88.  ...   88
 `88888P' dP    dP `88888P8 dP       `88888P' `88888P'   dP

*/
// type Range = [number, number];
// type Charset = Array<Range>;
// function ch(s: string): number {
//     return s.codePointAt(0) ?? 0;
// }
// function chRng(s: string): Range {
//     return [ch(s), ch(s)];
// }
// export const NUMER: Charset = [[ch("0"), ch("9")]];
// export const ALPHA: Charset = [
//     [ch("A"), ch("Z")],
//     [ch("a"), ch("z")],
// ];
// export const ALPNU: Charset = [...NUMER, ...ALPHA];
// export const IDENT: Charset = [...ALPNU, chRng("_")];
// export const ASCII: Charset = [[ch(" "), ch("~")]];
// void new CharsetList({ base: IDENTIFIER, inclide: "-.", exclude: "_" });
