/**
 * Attempting to use yup validation framework.
 * @module data/yup-form-validation
 * @experimental
 */
export type YupValidationSettings = {
    schema?: unknown;
    on?: "submit" | "blur" | "change";
    revalidate?: boolean;
    delay?: boolean;
    inline?: boolean;
};
export declare const yupValidationDefaults: YupValidationSettings;
/** Svelte action to initialize Semantic UI Form component with validation.
 *
 * https://semantic-ui.com/behaviors/form.html
 *
 * Example:
```
    <form class="ui form" use:suiFormValidation={{ inline: true }} />
        <input class="ui input"  />
        <Data
            bind:value={name}
            validate={yup.string().email('Invalid email').required('Email is required')}
        />
        ...
        <div class="ui message error" />
    </div>
```
 * Fields are matched by 'id', 'name', or 'data-validate' attribute.
 * Create `<div class="ui message error" />` to display the messages.
 *
 * For Dropdown, use id of the select or inner input.
 * For Calendar, use id of the innermost input.
*/
export declare function formValidation(node: Element, settings?: YupValidationSettings): void;
